######################################################################################################################
# Name:         Bus Info Parser
# Author:       Kevin Vinding
# Description:  Opens text file containing extracted bus information, parses the text, and returns it as
#               a list of data points.
######################################################################################################################
import datapoint as dp
import os

KEYWORD = '#bus#'
KEYWORD_LENGTH = len(KEYWORD)
DELIMITER = '#'


# Parses a text file for data points and returns them as a list
def parse_text_file(file_name):
    data_point_list = list()
    try:
        text_file = open(file_name, 'r')
    except:
        if os.path.isfile(file_name):
            print('Error: File "{}" could not be opened!'.format(file_name))
        else:
            print('Error: File "{}" does not exist!'.format(file_name))
        return -1

    while True:
        current_text_line = text_file.readline()
        if not current_text_line:
            # End of text-file
            break

        new_data_point = string_to_data_point(current_text_line)
        if new_data_point is not None:
            data_point_list.append(new_data_point)

    text_file.close()
    return data_point_list


# Parses string for a data point and converts it into a data point
def string_to_data_point(string):
    keyword_index = string.rfind(KEYWORD)
    if keyword_index != -1:
        string_after_keyword = string[keyword_index + KEYWORD_LENGTH:]
        split_string = string_after_keyword.split(DELIMITER)
        new_data_point = dp.DataPoint(split_string[0], split_string[1], split_string[2], split_string[3])
        return new_data_point
    else:
        # No valid data point can be extraced from string
        return None
